// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef SYNDICATION_VERSION_H
#define SYNDICATION_VERSION_H

#define SYNDICATION_VERSION_STRING "6.23.0"
#define SYNDICATION_VERSION_MAJOR 6
#define SYNDICATION_VERSION_MINOR 23
#define SYNDICATION_VERSION_PATCH 0
#define SYNDICATION_VERSION ((6<<16)|(23<<8)|(0))

#endif
